==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ProxyConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ProxyConfigFluent<A extends io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBindAddress();
  public A withBindAddress(java.lang.String bindAddress);
  public java.lang.Boolean hasBindAddress();
  
  /**
   * Method is deprecated. use withBindAddress instead.
   */
  @java.lang.Deprecated
  public A withNewBindAddress(java.lang.String arg0);
  public java.lang.String getIptablesSyncPeriod();
  public A withIptablesSyncPeriod(java.lang.String iptablesSyncPeriod);
  public java.lang.Boolean hasIptablesSyncPeriod();
  
  /**
   * Method is deprecated. use withIptablesSyncPeriod instead.
   */
  @java.lang.Deprecated
  public A withNewIptablesSyncPeriod(java.lang.String arg0);
  public A addToProxyArguments(java.lang.String key,java.util.ArrayList<java.lang.String> value);
  public A addToProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public A removeFromProxyArguments(java.lang.String key);
  public A removeFromProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getProxyArguments();
  public <K,V>A withProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments);
  public java.lang.Boolean hasProxyArguments();
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ProxyConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ProxyConfigFluent<A extends io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBindAddress();
  public A withBindAddress(java.lang.String bindAddress);
  public java.lang.Boolean hasBindAddress();
  
  /**
   * Method is deprecated. use withBindAddress instead.
   */
  @java.lang.Deprecated
  public A withNewBindAddress(java.lang.String arg0);
  public java.lang.String getIptablesSyncPeriod();
  public A withIptablesSyncPeriod(java.lang.String iptablesSyncPeriod);
  public java.lang.Boolean hasIptablesSyncPeriod();
  
  /**
   * Method is deprecated. use withIptablesSyncPeriod instead.
   */
  @java.lang.Deprecated
  public A withNewIptablesSyncPeriod(java.lang.String arg0);
  public A addToProxyArguments(java.lang.String key,java.util.ArrayList<java.lang.String> value);
  public A addToProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public A removeFromProxyArguments(java.lang.String key);
  public A removeFromProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getProxyArguments();
  public <K,V>A withProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments);
  public java.lang.Boolean hasProxyArguments();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
